import React, { useState, useEffect } from "react";
import AppBar from "@mui/material/AppBar";
import Toolbar from "@mui/material/Toolbar";
import Typography from "@mui/material/Typography";
import Button from "@mui/material/Button";
import IconButton from "@mui/material/IconButton";
import Box from "@mui/material/Box";
import Header from "../Header";
import InputBase from "@mui/material/InputBase";
import SearchIcon from "@mui/icons-material/Search";
import AccountCircleIcon from "@mui/icons-material/AccountCircle";

const Navbar = () => {
  const [showHeader, setShowHeader] = useState(true);
  const [lastScrollPos, setLastScrollPos] = useState(0);

  useEffect(() => {
    const handleScroll = () => {
      const currentScrollPos = window.scrollY;

      if (currentScrollPos > lastScrollPos && currentScrollPos > 50) setShowHeader(false)
      else setShowHeader(true)

      setLastScrollPos(currentScrollPos);
    };

    window.addEventListener("scroll", handleScroll);

    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  }, [lastScrollPos]);

  return (
    <AppBar position="fixed" sx={{ backgroundColor: "background.black" }}>
      {/* Conditionally render the Header */}
      {showHeader && <Header />}

      <Toolbar>
        {/* Left Section: Logo */}
        <Typography
          variant="h6"
          sx={{
            flexGrow: 0,
            color: "white",
            letterSpacing: 10,
            mx: 20,
          }}
        >
          AMBER
        </Typography>

        {/* Center Section: Nav Items */}
        <Box
          sx={{
            flexGrow: 1,
            display: "flex",
            gap: 2,
          }}
        >
          <Button
            color="inherit"
            onClick={() => {
              window.location.href = "/products";
            }}
          >
            DISCOVER
          </Button>
          <Button
            color="inherit"
            onClick={() => {
              window.location.href = "/";
            }}
          >
            HOME
          </Button>
          <Button
            color="inherit"
            onClick={() => {
              window.location.href = "/products";
            }}
          >
            BEAUTY
          </Button>
          <Button
            color="inherit"
            onClick={() => {
              window.location.href = "/products";
            }}
          >
            SALE
          </Button>
        </Box>

        {/* Right Section: Search and Profile */}
        <Box sx={{ display: "flex", alignItems: "center", marginRight: 20 }}>
          <Box
            sx={{
              display: "flex",
              alignItems: "center",
              backgroundColor: "rgba(255, 255, 255, 0.15)",
              borderRadius: 1,
              padding: "0 8px",
            }}
          >
            <SearchIcon />
            <InputBase
              placeholder="Search…"
              sx={{
                color: "inherit",
              }}
            />
          </Box>
          <IconButton color="inherit">
            <AccountCircleIcon sx={{ color: "white" }} />
          </IconButton>
        </Box>
      </Toolbar>
    </AppBar>
  );
};

export default Navbar;
